@@ -3,32 +3,7 @@ import topologic
 
 class Aperture(topologic.Aperture):
     @staticmethod
-    def ByTopologyContext(topology, context):
-        """
-        Creates an aperture.
-
-        Parameters
-        ----------
-        topology : topologic.Topology
-            The input topology to which the aperture will belong
-        context : topologic.Context
-            The context of the aperture.
-
-        Returns
-        -------
-        topologic.Aperture
-            The created aperture.
-
-        """
-        aperture = None
-        try:
-            aperture = topologic.Aperture.ByTopologyContext(topology, context)
-        except:
-            aperture = None
-        return aperture
-
-    @staticmethod
-    def ApertureTopology(aperture):
+    def ApertureTopology(aperture: topologic.Aperture) -> topologic.Topology:
         """
         Returns the topology of the input aperture.
         
@@ -43,4 +18,29 @@ class Aperture(topologic.Aperture):
             The topology of the input aperture.
 
         """
-        return topologic.Aperture.Topology(aperture)
\ No newline at end of file
+        return topologic.Aperture.Topology(aperture)
+
+    @staticmethod
+    def ByTopologyContext(topology: topologic.Topology, context: topologic.Context) -> topologic.Aperture:
+        """
+        Creates an aperture object represented by the input topology and one that belongs to the input context.
+
+        Parameters
+        ----------
+        topology : topologic.Topology
+            The input topology that represents the aperture.
+        context : topologic.Context
+            The context of the aperture. See Context class.
+
+        Returns
+        -------
+        topologic.Aperture
+            The created aperture.
+
+        """
+        aperture = None
+        try:
+            aperture = topologic.Aperture.ByTopologyContext(topology, context)
+        except:
+            aperture = None
+        return aperture
\ No newline at end of file
